@@ -1,8 +1,18 @@
 import json
+import sys
 
 import pytest
 from marshmallow import Schema
-from marshmallow.fields import DateTime, Dict, Field, List, Nested, String, TimeDelta
+from marshmallow.fields import (
+    DateTime,
+    Dict,
+    Field,
+    Int,
+    List,
+    Nested,
+    String,
+    TimeDelta,
+)
 
 from apispec import APISpec
 from apispec.exceptions import APISpecError
@@ -12,7 +22,6 @@ from .schemas import (
     AnalysisSchema,
     AnalysisWithListSchema,
     DefaultValuesSchema,
-    OrderedSchema,
     PatternedObjectSchema,
     PetSchema,
     RunSchema,
@@ -1246,8 +1255,19 @@ class TestSelfReference:
         }
 
 
-class TestOrderedSchema:
-    def test_ordered_schema(self, spec):
+class TestFieldOrdering:
+    def test_field_order_preserved(self, spec):
+        class OrderedSchema(Schema):
+            field1 = Int()
+            field2 = Int()
+            field3 = Int()
+            field4 = Int()
+            field5 = Int()
+            if sys.version_info < (3, 10):
+
+                class Meta:
+                    ordered = True
+
         spec.components.schema("Ordered", schema=OrderedSchema)
         result = get_schemas(spec)["Ordered"]["properties"]
         assert list(result.keys()) == ["field1", "field2", "field3", "field4", "field5"]
@@ -1296,6 +1316,14 @@ class TestDictValues:
         result = get_schemas(spec)["SchemaWithDict"]["properties"]["dict_field"]
         assert result == {"type": "object", "additionalProperties": {}}
 
+    def test_dict_with_empty_values_field_and_metadata(self, spec):
+        class SchemaWithDict(Schema):
+            dict_field = Dict(metadata={"additionalProperties": True})
+
+        spec.components.schema("SchemaWithDict", schema=SchemaWithDict)
+        result = get_schemas(spec)["SchemaWithDict"]["properties"]["dict_field"]
+        assert result == {"type": "object", "additionalProperties": True}
+
     def test_dict_with_nested(self, spec):
         class SchemaWithDict(Schema):
             dict_field = Dict(values=Nested(PetSchema))
