@@ -1,3 +1,4 @@
+import importlib.metadata
 from datetime import datetime
 
 import pytest
@@ -10,6 +11,8 @@ from apispec.ext.marshmallow import MarshmallowPlugin, OpenAPIConverter
 from .schemas import CustomList, CustomStringField
 from .utils import build_ref, get_schemas, validate_spec
 
+MA_VERSION = Version(importlib.metadata.version("marshmallow"))
+
 
 class TestMarshmallowFieldToOpenAPI:
     def test_fields_with_load_default_load(self, openapi):
@@ -133,6 +136,13 @@ class TestMarshmallowSchemaToModelDefinition:
         res = openapi.schema2jsonschema(WhiteStripesSchema)
         assert set(res["properties"].keys()) == {"guitarist", "drummer"}
 
+    def test_unknown_values_default_disallow(self, openapi):
+        class UnknownDefaultSchema(Schema):
+            first = fields.Str()
+
+        res = openapi.schema2jsonschema(UnknownDefaultSchema)
+        assert res["additionalProperties"] is False
+
     def test_unknown_values_disallow(self, openapi):
         class UnknownRaiseSchema(Schema):
             class Meta:
@@ -163,6 +173,30 @@ class TestMarshmallowSchemaToModelDefinition:
         res = openapi.schema2jsonschema(UnknownExcludeSchema)
         assert "additionalProperties" not in res
 
+    @pytest.mark.parametrize("meta_unknown", (RAISE, INCLUDE, EXCLUDE, None))
+    @pytest.mark.parametrize(
+        "instance_unknown,expected", ((RAISE, False), (INCLUDE, True), (EXCLUDE, None))
+    )
+    def test_unknown_values_instance_override_meta(
+        self, openapi, instance_unknown, expected, meta_unknown
+    ):
+        class UnknownSchema(Schema):
+            if meta_unknown is not None:
+
+                class Meta:
+                    unknown = meta_unknown
+
+            first = fields.Str()
+
+        res = openapi.schema2jsonschema(UnknownSchema(unknown=instance_unknown))
+        if expected is None:
+            assert "additionalProperties" not in res
+        else:
+            assert res["additionalProperties"] is expected
+
+    @pytest.mark.skipif(
+        MA_VERSION.major >= 4, reason="marshmallow 4 drop inferred fields"
+    )
     def test_only_explicitly_declared_fields_are_translated(self, openapi):
         class UserSchema(Schema):
             _id = fields.Int()
